Summary: The Cyrus Simple Authentication and Security Layer (SASL) library
Name: cyrus-sasl
Version: 2.1.28
Release: 5%{?dist}
License: BSD with advertising
URL: https://www.cyrusimap.org/sasl/
Source0: https://github.com/cyrusimap/cyrus-sasl/releases/download/cyrus-sasl-%{version}/cyrus-sasl-%{version}.tar.gz
Source1: saslauthd.service
Source2: saslauthd.sysconfig

Patch3000: cyrus-sasl-no_rpath.patch

BuildRequires: make, autoconf, automake, libtool, gdbm-devel, groff
BuildRequires: krb5-devel >= 1.2.2, openssl-devel, pam-devel, pkgconfig
BuildRequires: mariadb-connector-c-devel, libpq-devel, zlib-devel
BuildRequires: openldap-devel, libdb-devel-static
BuildRequires: python3 nss_wrapper krb5-server
Requires: %{name}-lib = %{version}-%{release}
Requires(pre): /usr/sbin/useradd /usr/sbin/groupadd
Requires(postun): /usr/sbin/userdel /usr/sbin/groupdel
Requires: /sbin/nologin, systemd >= 211
Provides: user(saslauth), group(saslauth)


%description
Simple Authentication and Security Layer (SASL) is a specification
that describes how authentication mechanisms can be plugged into an
application protocol on the wire. Cyrus SASL is an implementation
of SASL that makes it easy for application developers to integrate
authentication mechanisms into their application in a generic way.

%package lib
Summary: Shared libraries needed by applications which use Cyrus SASL

%description lib
This package provides shared libraries which are needed by
applications which use the Cyrus SASL.

%package devel
Summary: Files needed for developing applications with Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package provides header files and DSO for developers who use Cyrus SASL
library.

%package gssapi
Summary: GSSAPI authentication support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description gssapi
This package contains the Cyrus SASL plugins which support GSSAPI
authentication.

%package plain
Summary: PLAIN and LOGIN authentication support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description plain
This package provides the Cyrus SASL plugins which support
PLAIN and LOGIN authentication.

%package md5
Summary: CRAM-MD5 and DIGEST-MD5 authentication support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description md5
This package provides the Cyrus SASL plugins which support
CRAM-MD5 and DIGEST-MD5 authentication.

%package ntlm
Summary: NTLM authentication support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description ntlm
This package provides the Cyrus SASL plugins which support
the NTLM authentication.

%package sql
Summary: SQL auxprop support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description sql
This package provides the Cyrus SASL plugins which support
using a RDBMS.

%package ldap
Summary: LDAP auxprop support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description ldap
This package provides the Cyrus SASL plugins which support
using a directory server, accessed using LDAP.

%package scram
Summary: SCRAM auxprop support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description scram
This package provides the Cyrus SASL plugins which support
the SCRAM authentication.

%package gs2
Summary: GS2 support for Cyrus SASL
Requires: %{name}-lib = %{version}-%{release}

%description gs2
This package provides the Cyrus SASL plugins which support
the GS2 authentication.

%prep
%setup -q -n cyrus-sasl-%{version}
%patch3000 -p1

%build
autoreconf -f

krb5_prefix=`krb5-config --prefix`
if test x$krb5_prefix = x%{_prefix} ; then
        krb5_prefix=
else
        CPPFLAGS="-I${krb5_prefix}/include $CPPFLAGS"; export CPPFLAGS
        LDFLAGS="-L${krb5_prefix}/%{_lib} $LDFLAGS"; export LDFLAGS
fi

LIBS="-lcrypt"; export LIBS
if pkg-config openssl ; then
        CPPFLAGS="`pkg-config --cflags-only-I openssl` $CPPFLAGS"; export CPPFLAGS
        LDFLAGS="`pkg-config --libs-only-L openssl` $LDFLAGS"; export LDFLAGS
fi

INC_DIR="`mysql_config --include`"
if test x"$INC_DIR" != "x-I%{_includedir}"; then
        CPPFLAGS="$INC_DIR $CPPFLAGS"; export CPPFLAGS
fi
LIB_DIR="`mysql_config --libs | sed -e 's,-[^L][^ ]*,,g' -e 's,^ *,,' -e 's, *$,,' -e 's,  *, ,g'`"
if test x"$LIB_DIR" != "x-L%{_libdir}"; then
        LDFLAGS="$LIB_DIR $LDFLAGS"; export LDFLAGS
fi

INC_DIR="-I`pg_config --includedir`"
if test x"$INC_DIR" != "x-I%{_includedir}"; then
        CPPFLAGS="$INC_DIR $CPPFLAGS"; export CPPFLAGS
fi
LIB_DIR="-L`pg_config --libdir`"
if test x"$LIB_DIR" != "x-L%{_libdir}"; then
        LDFLAGS="$LIB_DIR $LDFLAGS"; export LDFLAGS
fi

export CFLAGS="$RPM_OPT_FLAGS $CFLAGS $CPPFLAGS -fPIC -pie -Wl,-z,relro -Wl,-z,now"

%configure \
        --enable-shared --disable-static \
        --disable-java \
        --with-plugindir=%{_libdir}/sasl2 \
        --with-configdir=%{_libdir}/sasl2:%{_sysconfdir}/sasl2 \
        --disable-krb4 \
        --enable-gssapi${krb5_prefix:+=${krb5_prefix}} \
        --with-gss_impl=mit \
        --with-rc4 \
        --with-dblib=gdbm \
        --with-dbpath=/etc/sasl2/sasldb2 \
        --with-saslauthd=/run/saslauthd --without-pwcheck \
        --with-ldap \
        --with-devrandom=/dev/urandom \
        --enable-anon \
        --enable-cram \
        --enable-digest \
        --enable-ntlm \
        --enable-plain \
        --enable-login \
        --enable-alwaystrue \
        --enable-httpform \
        --disable-otp \
        --enable-ldapdb \
        --enable-sql --with-mysql=yes --with-pgsql=yes \
        --without-sqlite \
        "$@"
make sasldir=%{_libdir}/sasl2
make -C saslauthd testsaslauthd
make -C sample


%install
test "%{buildroot}" != "/" && rm -rf %{buildroot}

make install DESTDIR=%{buildroot} sasldir=%{_libdir}/sasl2

install -m755 -d %{buildroot}%{_bindir}
install -m755 sample/client %{buildroot}%{_bindir}/sasl2-sample-client
install -m755 sample/server %{buildroot}%{_bindir}/sasl2-sample-server
install -m755 saslauthd/testsaslauthd %{buildroot}%{_sbindir}/testsaslauthd

install -m755 -d %{buildroot}%{_mandir}/man8/
install -m644 -p saslauthd/saslauthd.mdoc %{buildroot}%{_mandir}/man8/saslauthd.8
install -m644 -p saslauthd/testsaslauthd.8 %{buildroot}%{_mandir}/man8/testsaslauthd.8

install -m755 -d %{buildroot}/%{_unitdir} %{buildroot}/etc/sysconfig
install -m644 -p %{SOURCE1} %{buildroot}/%{_unitdir}/saslauthd.service
install -m644 -p %{SOURCE2} %{buildroot}/etc/sysconfig/saslauthd

install -m755 -d %{buildroot}/%{_sysconfdir}/sasl2
install -m755 -d %{buildroot}/%{_libdir}/sasl2

rm -f %{buildroot}%{_libdir}/sasl2/libotp.*
rm -f %{buildroot}%{_libdir}/sasl2/*.a
rm -f %{buildroot}%{_libdir}/sasl2/*.la
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_mandir}/cat8/saslauthd.8

%check
make check %{?_smp_mflags}

%pre
getent group saslauth >/dev/null || groupadd -g 76 -r saslauth
getent passwd saslauth >/dev/null || useradd -r -g saslauth -d /run/saslauthd -s /sbin/nologin saslauth

%post
%systemd_post saslauthd.service

%preun
%systemd_preun saslauthd.service

%postun
%systemd_postun_with_restart saslauthd.service

%files
%license COPYING
%doc AUTHORS saslauthd/LDAP_SASLAUTHD
%{_sbindir}/pluginviewer
%{_sbindir}/saslauthd
%{_sbindir}/testsaslauthd
%config(noreplace) /etc/sysconfig/saslauthd
%{_unitdir}/saslauthd.service
%ghost /run/saslauthd
%{_mandir}/man8/*

%files lib
%doc doc/html/*.html
%{_libdir}/libsasl*.so.*
%dir %{_libdir}/sasl2/
%{_libdir}/sasl2/*anonymous*.so*
%{_libdir}/sasl2/*sasldb*.so*
%{_sbindir}/saslpasswd2
%{_sbindir}/sasldblistusers2
%dir %{_sysconfdir}/sasl2

%files plain
%{_libdir}/sasl2/*plain*.so*
%{_libdir}/sasl2/*login*.so*

%files ldap
%{_libdir}/sasl2/*ldapdb*.so*

%files md5
%{_libdir}/sasl2/*crammd5*.so*
%{_libdir}/sasl2/*digestmd5*.so*

%files ntlm
%{_libdir}/sasl2/*ntlm*.so*

%files sql
%{_libdir}/sasl2/*sql*.so*

%files gssapi
%{_libdir}/sasl2/*gssapi*.so*

%files scram
%{_libdir}/sasl2/libscram.so*

%files gs2
%{_libdir}/sasl2/libgs2.so*

%files devel
%{_bindir}/sasl2-sample-client
%{_bindir}/sasl2-sample-server
%{_includedir}/*
%{_libdir}/libsasl*.*so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.1.28-5
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.1.28-4
- Rebuilt for OpenCloudOS Stream 23

* Wed Feb 22 2023 cunshunxia <cunshunxia@tencent.com> - 2.1.28-3
- remove unused macros.

* Wed Feb 15 2023 Shuo Wang <abushwang@tencent.com> - 2.1.28-2
- remove unused buildrequires socket_wrapper

* Wed Jun 8 2022 cunshunxia <cunshunxia@tencent.com> - 2.1.28-1
- initial build
